@@ -17,7 +17,9 @@ class reverse_key:
 ENV = {
     "__builtins__": {},
     "datetime": datetime,
+    "locals": locals,
     "re": re,
+    "bool": bool,
     "float": float,
     "int": int,
     "str": str,
